@@ -11,7 +11,7 @@
 #' @param ncores Number of cores used. The parallelization will take place only if OpenMP is supported.
 #' @param isChol boolean set to true is \code{sigma} is the cholesky decomposition of the covariance matrix.
 #' @return A vector of length n where the i-the entry contains the pdf of the i-th random vector.
-#' @details There are in fact many candidates for the multivariate generalization of Student's t-distribution, here we use
+#' @details There are many candidates for the multivariate generalization of Student's t-distribution, here we use
 #'          the parametrization described here \url{https://en.wikipedia.org/wiki/Multivariate_t-distribution}. NB: at the moment 
 #'          the parallelization does not work properly on Solaris OS when \code{ncores>1}. Hence, \code{dmvt()} checks if the OS 
 #'          is Solaris and, if this the case, it imposes \code{ncores==1}. 
@@ -39,6 +39,8 @@ dmvt <- function(X, mu, sigma, df, log = FALSE, ncores = 1, isChol = FALSE){
   
   if(df <= 0.0) stop("df must be positive.")
   
+  if(df == Inf){ df <- -1 } # Fall back on multivariate normal case
+  
   if( ncores > 1 && grepl('SunOS', Sys.info()['sysname']) ){
     
     message("dmvt() cannot be used on multiple cores under Solaris. I am resetting \"ncores\" to 1.")
@@ -54,6 +56,5 @@ dmvt <- function(X, mu, sigma, df, log = FALSE, ncores = 1, isChol = FALSE){
          df_ = df,
          log_ = log, 
          ncores_ = ncores,
-         isChol_ = isChol, 
-         PACKAGE = "mvnfast" )
+         isChol_ = isChol)
 }
