@@ -10,6 +10,9 @@
 #' @param A an (optional) numeric matrix of dimension (n x d), which will be used to store the output random variables.
 #'        It is useful when n and d are large and one wants to call \code{rmvn()} several times, without reallocating memory
 #'        for the whole matrix each time. NB: the element of \code{A} must be of class "numeric".
+#' @param kpnames if \code{TRUE} the dimensions' names are preserved. That is, the i-th column of the output
+#'                has the same name as the i-th entry of \code{mu} or the i-th column of \code{sigma}. 
+#'                \code{kpnames==FALSE} by default.
 #' @return If \code{A==NULL} (default) the output is an (n x d) matrix where the i-th row is the i-th simulated vector.
 #'         If \code{A!=NULL} then the random vector are store in \code{A}, which is provided by the user, and the function
 #'         returns \code{NULL}.
@@ -51,7 +54,7 @@
 #' 
 #' @export rmvn
 
-rmvn <- function(n, mu, sigma, ncores = 1, isChol = FALSE, A = NULL)
+rmvn <- function(n, mu, sigma, ncores = 1, isChol = FALSE, A = NULL, kpnames = FALSE)
 {
   d <- length(mu)
   
@@ -85,6 +88,12 @@ rmvn <- function(n, mu, sigma, ncores = 1, isChol = FALSE, A = NULL)
          isChol_ = isChol, 
          A_ = A )
   
+  if( kpnames ) # (Optionally add dimensions names)
+  {
+   if( is.null(nam <- names(mu)) ){ nam <- dimnames(sigma)[[1L]] }
+   if( !is.null(nam) ){ dimnames(A) <- list(NULL, nam) }
+  }
+
   # Return a matrix if no storage was provided and NULL if it was provided.
   if( retMat ) {
     return( A );
